import davtelepot

from .messages import elevation_messages


async def elevate_to_admin(bot: davtelepot.bot.Bot, language: str, user_record: dict):
    if len(bot.administrators) < 1:
        user_record['privileges'] = 1
        bot.db['users'].upsert(
            user_record,
            ['id']
        )
        return bot.get_message('elevation', 'granted', language=language)
    return bot.get_message('elevation', 'denied', language=language)


async def set_chat(bot: davtelepot.bot.Bot, update: dict, language: str):
    await bot.delete_message(update=update)
    if 'chat' in update and 'id' in update['chat']:
        chat_id = update['chat']['id']
        if chat_id > 0:
            return bot.get_message('elevation',
                                   'chat_not_set',
                                   language=language)
        bot.db['information'].upsert(
            dict(
                name='bic_chat_id',
                value=chat_id
            ),
            ['name']
        )
        bot.shared_data['bic_chat_id'] = chat_id
        await bot.send_message(chat_id=update['from']['id'],
                               text=bot.get_message('elevation',
                                                    'chat_set',
                                                    chat_id=chat_id,
                                                    language=language))


def init(telegram_bot: davtelepot.bot.Bot):
    if 'information' not in telegram_bot.db.tables:
        table = telegram_bot.db.create_table('information')
    else:
        table = telegram_bot.db.get_table('information')
    if 'name' not in table.columns:
        table.create_column('name', telegram_bot.db.types.string(25))
    if 'value' not in table.columns:
        table.create_column('value', telegram_bot.db.types.string(100))
    telegram_bot.messages['elevation'] = elevation_messages
    bic_chat_id = telegram_bot.db['information'].find_one(name='bic_chat_id')
    if bic_chat_id is not None:
        bic_chat_id = int(bic_chat_id['value'])
    telegram_bot.shared_data['bic_chat_id'] = bic_chat_id

    @telegram_bot.command(command='elevate',
                          authorization_level='everybody')
    async def _elevate_to_admin(bot, language, user_record):
        return await elevate_to_admin(bot=bot, language=language, user_record=user_record)

    @telegram_bot.command(command='set_chat',
                          authorization_level='admin')
    async def _set_chat(bot, update, language):
        return await set_chat(bot=bot, update=update, language=language)
